@@ -1,5 +1,6 @@
 import urllib
 from strange_case.config_dict import config_copy
+from strange_case.registry import Registry
 
 
 def check_config_first(fn):
@@ -19,6 +20,8 @@ class Node(object):
     Parent class for all nodes (pages and folders)
     """
 
+    # stores the tracked files, which is used to write the timestamps file
+    files_tracked = []
     # stores a list of files written, so that stale files can be removed
     files_written = []
 
@@ -127,8 +130,6 @@ class Node(object):
         ret = [self]
         while current.parent:
             for page in current.parent.all():
-                if 'is_index' not in page.config:
-                    print page.config
                 if page.config['is_index'] and page != self:
                     ret.insert(0, page)
                     break
@@ -245,10 +246,28 @@ class Node(object):
         if key in self.config:
             return self.config.get(key)
 
-        for child in self.children:
-            if child.name == key:
-                return child
-        raise AttributeError
+        child_by_name = [child for child in self.children if child.name == key]
+        if len(child_by_name) > 1:
+            raise KeyError('There are multiple results for the node named "{}" '
+                'in folder "{}"'.format(key, self.name))
+        elif child_by_name:
+            return child_by_name[0]
+
+        # look for a "pointer" attribute
+        if not key.endswith(' ->'):
+            try:
+                ret = self[key + ' ->']
+                path = ret.split('.')
+                assert path.pop(0) == 'site'
+                search_in = Registry.get('root')
+                while path:
+                    part = path.pop(0)
+                    search_in = search_in[part]
+                return search_in
+            except AttributeError:
+                pass
+
+        raise AttributeError(key)
 
     def __len__(self):
         return len([child for child in self.children if child.iterable])
@@ -259,5 +278,8 @@ class Node(object):
     def __contains__(self, obj):
         return obj in self.children
 
+    def __str__(self, indent=''):
+        return self.url
+
     def __repr__(self, indent=''):
         return "%s<url: %s type:%s>" % (indent, self.url, str(type(self)))
